# altcos-common

Библиотека для удобного взаимодейтсвия с `altcos`-репозиториями.

# Примеры

[Информация о последнем коммите](examples/last_commit_info.py)

[Получение коммита по версии](examples/commit_by_version.py)
